@@ -27,11 +27,8 @@ where
                 ast.imports.iter().map(|i| i.get_qualified_name()).collect();
 
             // Declared parcelables as qualified names
-            let declared_parcelables: HashSet<String> = ast
-                .declared_parcelables
-                .iter()
-                .map(|i| i.get_qualified_name())
-                .collect();
+            let declared_parcelables: HashSet<String> =
+                ast.imports.iter().map(|i| i.get_qualified_name()).collect();
 
             // Resolve types (check custom types and set definition if found in imports)
             let resolved = resolve_types(
@@ -235,16 +232,13 @@ fn check_declared_parcelables(
     let declared_parcelables: HashMap<String, &ast::Import> =
         declared_parcelables
             .iter()
-            .fold(HashMap::new(), |mut map, declared_parcelable| {
-                let qualified_name = declared_parcelable.get_qualified_name();
+            .fold(HashMap::new(), |mut map, import| {
+                let qualified_name = import.get_qualified_name();
 
-                if let Some((_, conflicting_import)) = imports
-                    .iter()
-                    .find(|(_, import)| import.name == declared_parcelable.name)
-                {
+                if let Some(conflicting_import) = imports.get(&qualified_name) {
                     diagnostics.push(Diagnostic {
                         kind: DiagnosticKind::Error,
-                        range: declared_parcelable.symbol_range.clone(),
+                        range: import.symbol_range.clone(),
                         message: format!(
                             "Declared parcelable conflicts with import `{}`",
                             qualified_name
@@ -264,7 +258,7 @@ fn check_declared_parcelables(
                     hash_map::Entry::Occupied(previous) => {
                         diagnostics.push(Diagnostic {
                             kind: DiagnosticKind::Error,
-                            range: declared_parcelable.symbol_range.clone(),
+                            range: import.symbol_range.clone(),
                             message: format!(
                                 "Multiple parcelable declarations `{}`",
                                 qualified_name
@@ -278,20 +272,20 @@ fn check_declared_parcelables(
                         });
                     }
                     hash_map::Entry::Vacant(v) => {
-                        v.insert(declared_parcelable);
+                        v.insert(import);
                     }
                 }
                 map
             });
 
     // - generate diagnostics for unrecommended usage and for unused declared parcelables
-    for (qualified_import, declared_parcelable) in declared_parcelables.into_iter() {
+    for (qualified_import, import) in declared_parcelables.into_iter() {
         if !resolved.contains(&qualified_import) {
             // No type resolved for this import
             diagnostics.push(Diagnostic {
                 kind: DiagnosticKind::Warning,
-                range: declared_parcelable.symbol_range.clone(),
-                message: format!("Unused declared parcelable `{}`", declared_parcelable.name),
+                range: import.symbol_range.clone(),
+                message: format!("Unused declared parcelable `{}`", import.name),
                 context_message: Some("unused declared parcelable".to_owned()),
                 hint: None,
                 related_infos: Vec::new(),
@@ -299,8 +293,8 @@ fn check_declared_parcelables(
         } else {
             diagnostics.push(Diagnostic {
                 kind: DiagnosticKind::Warning,
-                range: declared_parcelable.symbol_range.clone(),
-                message: format!("Usage of declared parcelable `{}`", declared_parcelable.name),
+                range: import.symbol_range.clone(),
+                message: format!("Usage of declared parcelable `{}`", import.name),
                 context_message: Some(String::from("declared parcelable")),
                 hint: Some(String::from("It is recommended to defined parcelables in AIDL to garantee compatilibity between languages")),
                 related_infos: Vec::new(),
@@ -822,7 +816,7 @@ mod tests {
         ]);
 
         let import = ast::Import {
-            path: "test.other.path".into(),
+            path: "test.path".into(),
             name: "AlreadyImported".into(),
             symbol_range: utils::create_range(1),
             full_range: utils::create_range(1),
